@@ -35,7 +35,10 @@ class AndroidLayout(BaseDashboardLayout):
     edit_template_name = 'android/edit_layout.html'
     placeholders = [AndroidMainPlaceholder, AndroidShortcutsPlaceholder]
     cell_units = 'px'
-    media_css = ('css/dash_layout_android.css',)
+    media_css = (
+        'css/dash_dotted_borders.css',
+        'css/dash_layout_android.css',
+    )
     #media_js = ('js/dash_layout_android.js',)
 
 
